@@ -2,6 +2,7 @@ var group__pw__utils =
 [
     [ "strndupa", "group__pw__utils.html#ga8869815cdd42998571019730afd248ff", null ],
     [ "strdupa", "group__pw__utils.html#ga8927bee5a1c2d50bf44dffc697b24840", null ],
+    [ "pw_rand32", "group__pw__utils.html#gae06596c091a3ae4ddd2b262deec5bd34", null ],
     [ "PW_DEPRECATED", "group__pw__utils.html#ga97004c44df1cac3ac75257c40ff8ce58", null ],
     [ "pw_destroy_t", "group__pw__utils.html#ga40eebfe720dbba23dbc86347dd95ba0b", null ],
     [ "pw_split_walk", "group__pw__utils.html#ga86777dfdd21dbb21a2c74470aad019a4", null ],
@@ -10,5 +11,6 @@ var group__pw__utils =
     [ "pw_free_strv", "group__pw__utils.html#ga80e0ca15ccef3f20ef9524a26d8c2b45", null ],
     [ "pw_strip", "group__pw__utils.html#gab7c0e5ea4acd296a58642198133565c9", null ],
     [ "pw_getrandom", "group__pw__utils.html#gac9f252f07455653aebd285fc9e05feee", null ],
+    [ "pw_random", "group__pw__utils.html#ga7679af5adec2035204ca26a2b5616b6d", null ],
     [ "pw_reallocarray", "group__pw__utils.html#ga9349b2873f42849a409d3526fd874ecc", null ]
 ];
\ No newline at end of file
