@@ -63,26 +63,27 @@ var NAVTREEINDEX =
 [
 "alloc_8h.html",
 "group__pw__client.html#gaffa5b807a9674495aa5c14a68d5fd88c",
-"group__pw__global.html#gaf901fcdcb9d2059370fdd9d6ad188c3f",
-"group__pw__keys.html#gaae4d17260ca60c2ab5e2c8d32b989d67",
-"group__pw__node.html#ga91a6a1a257b75f8a6fd5eb6755447a59",
-"group__pw__session__manager.html#ga3e4945a8ef7615d8e4b574209890a68b",
-"group__pwtest.html#ga60aaaf4bca029a7cd77d9e2328cc33b0",
-"group__spa__dbus.html#ga86263eb7e15c01e44c67b4b92c777a45",
-"group__spa__keys.html#ga397212748e5208c2727994b89ab56b04",
-"group__spa__node.html#ga4057156d1eaf9f13cab72a187735ad65",
-"group__spa__param.html#ga7f188485cf47ffb05c8f6be407448f2c",
-"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbca4c1b239852626671b53906f9d9b89e42",
-"group__spa__param.html#ggab89b8affc8ad458b2cc10dd9e8423fe7acb6b47253078f2060df6af90fdedaf27",
-"group__spa__pod.html#ga1d4549904c233c319e9a6222d7781948",
-"group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067fa82fbd414410e306dc9e4cf3a2ac4dc78",
-"hook_8h.html",
-"page_spa_design.html#autotoc_md130",
-"structpw__data__loop__events.html#a5ee1e79472b7ab5aab28d40df7a1db0b",
-"structpw__memchunk.html",
-"structspa__audio__info.html",
-"structspa__io__segment.html#ab725d4cd7f8cb1a44abe185ac504fd1c",
-"structspa__pod__object.html"
+"group__pw__global.html#gae35b9eb5ebbdead2e5a79845d5fa2031",
+"group__pw__keys.html#gaa2674ee0552a3f30a0446eb0461741d6",
+"group__pw__node.html#ga3db541c9ec1c2245fe17402135979f2d",
+"group__pw__session__manager.html#ga2de263210f215bfe195aa672b33168d3",
+"group__pwtest.html#ga1f365422ab4403a3f3799b3667e01ff4",
+"group__spa__cpu.html#gade1463bb6f0e53ab480be27ac0b4383c",
+"group__spa__json.html#ga8e5fa24c312810edffc063169e55497d",
+"group__spa__names.html#gaea2a7f9455eba0d3fb89870950c0c94d",
+"group__spa__param.html#ga4b41f63cb5b094caa8fa328bdac052e5",
+"group__spa__param.html#gga339d759aafadca6ef623f32ce7e65be0a871dcd85dad60d460bbad9176d23d048",
+"group__spa__param.html#gga9c37ad62772233835d6bf5083a9e4613ad6dae916837199443be552bd7e8f1fa8",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43eadeda74b6a7caa8d6d795177202601142",
+"group__spa__pod.html#gabc8a77a767e20163e368ed09ab01f527",
+"group__spa__utils__defs.html#ga3bca1a11d1c7e8404f9456580acf0676",
+"page_objects_design.html#autotoc_md72",
+"structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392",
+"structpw__impl__module__events.html#a1f0de76c49fdf742fe40c6fc0799d08c",
+"structpw__session__events.html#a6d9e402e306432f33e6fe085599416d7",
+"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0",
+"structspa__meta__header.html#a1410208fd9ccdd153418f01d5ce12d7b",
+"structspa__system__methods.html#ada4083f64959db28b4a03f4032ee87e9"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
