@@ -8,21 +8,21 @@ var NAVTREEINDEX0 =
 "audio-dsp-filter_8c-example.html":[13,8],
 "audio-dsp-src_8c-example.html":[13,7],
 "audio-src_8c-example.html":[13,6],
-"audio_2raw_8h.html":[10,8,7,4],
+"audio_2raw-types_8h.html":[10,8,7,4],
+"audio_2raw_8h.html":[10,8,7,5],
 "audio_8h.html":[10,8,7,6],
 "bluez-session_8c-example.html":[13,23],
 "buffer_2buffer_8h.html":[10,8,1,1],
 "buffer_2type-info_8h.html":[10,8,1,3],
-"buffers_8h.html":[10,5,9,0],
+"buffers-types_8h.html":[10,8,7,8],
 "builder_8h.html":[10,8,0,0],
-"chroma_8h.html":[10,8,7,12],
+"chroma_8h.html":[10,8,7,24],
 "classes.html":[11,1],
 "client-node_8h.html":[10,7,0,0],
 "client_8h.html":[10,4,3,0],
-"color_8h.html":[10,8,7,13],
+"color_8h.html":[10,8,7,25],
 "compare_8h.html":[10,8,0,2],
 "conf_8h.html":[10,6,1,0],
-"context_8h.html":[10,4,2,0],
 "control_2type-info_8h.html":[10,8,2,1],
 "core_8h.html":[10,4,14,0],
 "core_8h.html":[10,4,4,0],
@@ -30,18 +30,18 @@ var NAVTREEINDEX0 =
 "data-loop_8h.html":[10,5,11,0],
 "dbus_8h.html":[10,8,9,1,0],
 "debug_2buffer_8h.html":[10,8,3,0],
-"debug_2dict_8h.html":[10,8,3,1],
-"debug_2format_8h.html":[10,8,3,2],
-"debug_2pod_8h.html":[10,8,3,6],
+"debug_2dict_8h.html":[10,8,3,2],
+"debug_2format_8h.html":[10,8,3,3],
+"debug_2pod_8h.html":[10,8,3,7],
 "defs_8h.html":[10,8,8,1,0],
 "dsd_8h.html":[10,8,7,0],
-"encoded_8h.html":[10,8,7,14],
 "examples.html":[13],
 "export-sink_8c-example.html":[13,19],
 "export-source_8c-example.html":[13,20],
 "export-spa-device_8c-example.html":[13,22],
 "export-spa_8c-example.html":[13,21],
 "factory_8h.html":[10,4,6,0],
+"format-types_8h.html":[10,8,7,10],
 "functions.html":[11,2,0],
 "functions.html":[11,2,0,0],
 "functions_a.html":[11,2,0,1],
