@@ -1,5 +1,8 @@
 var NAVTREEINDEX15 =
 {
+"group__spa__utils__defs.html#ga3bca1a11d1c7e8404f9456580acf0676":[10,8,8,1,10],
+"group__spa__utils__defs.html#ga3d65c899d0f8937244ed2893d1841f6f":[10,8,8,1,46],
+"group__spa__utils__defs.html#ga3fecbba7e4f85f539f62c8db39f12b0a":[10,8,8,1,58],
 "group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5":[10,8,8,1,74],
 "group__spa__utils__defs.html#ga4a50fbd4b694e2826233b6d54ef3b5a8":[10,8,8,1,67],
 "group__spa__utils__defs.html#ga4a52677c41f0a787a3c6624f18647cb6":[10,8,8,1,43],
@@ -246,8 +249,5 @@ var NAVTREEINDEX15 =
 "page_objects_design.html#autotoc_md68":[5,8,0],
 "page_objects_design.html#autotoc_md69":[5,8,0,0],
 "page_objects_design.html#autotoc_md70":[5,8,0,1],
-"page_objects_design.html#autotoc_md71":[5,8,0,2],
-"page_objects_design.html#autotoc_md72":[5,8,1],
-"page_objects_design.html#autotoc_md73":[5,8,1,0],
-"page_objects_design.html#autotoc_md74":[5,8,1,0,0]
+"page_objects_design.html#autotoc_md71":[5,8,0,2]
 };
