@@ -1,5 +1,8 @@
 var NAVTREEINDEX18 =
 {
+"structpw__impl__module__events.html#a1f0de76c49fdf742fe40c6fc0799d08c":[10,5,6,1,3],
+"structpw__impl__module__events.html#a2cb2abff60d0fa2370afcb8b5c2ae830":[10,5,6,1,2],
+"structpw__impl__module__events.html#a4cfcceec669bbbdf6697e36cd5dbae1d":[10,5,6,1,1],
 "structpw__impl__module__events.html#a75c9588d21472e8d610b813bdd9a419e":[10,5,6,1,4],
 "structpw__impl__module__events.html#aea5e86ba050b1b9e92bb3c7ba3425f71":[10,5,6,1,0],
 "structpw__impl__node.html":[10,5,7,2],
@@ -246,8 +249,5 @@ var NAVTREEINDEX18 =
 "structpw__resource__events.html#af8ab8db63d0b4e3a332ff552e416e5a2":[10,5,14,1,3],
 "structpw__session.html":[10,7,4,24],
 "structpw__session__events.html":[10,7,4,10],
-"structpw__session__events.html#a36371c5decff93c9c0c0688c19b2780c":[10,7,4,10,1],
-"structpw__session__events.html#a6d9e402e306432f33e6fe085599416d7":[10,7,4,10,2],
-"structpw__session__events.html#a9156a82a54dba4f5e6f7b045a31b5ac7":[10,7,4,10,0],
-"structpw__session__info.html":[10,7,4,18]
+"structpw__session__events.html#a36371c5decff93c9c0c0688c19b2780c":[10,7,4,10,1]
 };
