@@ -1,5 +1,8 @@
 var NAVTREEINDEX19 =
 {
+"structpw__session__events.html#a6d9e402e306432f33e6fe085599416d7":[10,7,4,10,2],
+"structpw__session__events.html#a9156a82a54dba4f5e6f7b045a31b5ac7":[10,7,4,10,0],
+"structpw__session__info.html":[10,7,4,18],
 "structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93":[10,7,4,18,3],
 "structpw__session__info.html#a1289ec21ec9441f29314a561b341cf13":[10,7,4,18,2],
 "structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6":[10,7,4,18,1],
@@ -246,8 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__device__object__info.html#a0758afd0518197c48d5d76cdc14526e3":[10,8,4,5,0],
 "structspa__device__object__info.html#a4ed767ff310d6f2e1d4cd78f3a7c3f6f":[10,8,4,5,1],
 "structspa__device__object__info.html#a702111c5873243c93551073552863666":[10,8,4,5,3],
-"structspa__device__object__info.html#a9b6645d2c0b8b3679833ad122cb299a1":[10,8,4,5,2],
-"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0":[10,8,4,5,4],
-"structspa__dict.html":[10,8,8,2,2],
-"structspa__dict.html#a1f1083da3fcd51b9c3eb22cc8f1d54e0":[10,8,8,2,2,2]
+"structspa__device__object__info.html#a9b6645d2c0b8b3679833ad122cb299a1":[10,8,4,5,2]
 };
