@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"group__pw__node.html#ga3db541c9ec1c2245fe17402135979f2d":[10,4,10,10],
 "group__pw__node.html#ga5437fe007ac346f48f0f63fec8ca8b40":[10,4,10,19],
 "group__pw__node.html#ga551b316bd8df6636cd863b82d3f006e3":[10,4,10,25],
 "group__pw__node.html#ga5768e66e04bfef45e468df3e38158c93":[10,4,10,26],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "group__pw__session__manager.html#ga19f24c2c9fefe01f859c18ec29c2de8e":[10,7,4,164],
 "group__pw__session__manager.html#ga1c21ac4fad8f103846eb54b77422c6b1":[10,7,4,38],
 "group__pw__session__manager.html#ga1df3e3242c1438fe35c454dd3ed41219":[10,7,4,59],
-"group__pw__session__manager.html#ga294e1f89f88e8c143a0fdc10f6b5c19f":[10,7,4,136],
-"group__pw__session__manager.html#ga2de263210f215bfe195aa672b33168d3":[10,7,4,93]
+"group__pw__session__manager.html#ga294e1f89f88e8c143a0fdc10f6b5c19f":[10,7,4,136]
 };
