@@ -1,5 +1,8 @@
 var NAVTREEINDEX6 =
 {
+"group__pwtest.html#ga1f365422ab4403a3f3799b3667e01ff4":[10,2,14],
+"group__pwtest.html#ga235878471a0cc9e96ec3a167cd154f53":[10,2,26],
+"group__pwtest.html#ga288f936c9cb1fea769e8fcf616650ba5":[10,2,5],
 "group__pwtest.html#ga2c915fce91d56c38b5f5a3c4e58c43b2":[10,2,24],
 "group__pwtest.html#ga30b74c4eb3256e1c351bb036cb338990":[10,2,17],
 "group__pwtest.html#ga31aadf049c2da1eaa5735511d1cafef6":[10,2,37],
@@ -246,8 +249,5 @@ var NAVTREEINDEX6 =
 "group__spa__cpu.html#gacd9379b41a5fc4ca989f106515ab72e4":[10,8,9,0,54],
 "group__spa__cpu.html#gad24522ec05d1ded3a3d9b2a3274b0030":[10,8,9,0,30],
 "group__spa__cpu.html#gad4c6b81675ec1a16c23239041970f099":[10,8,9,0,12],
-"group__spa__cpu.html#gadbf1c05dc94b098500b335c980a20f73":[10,8,9,0,27],
-"group__spa__cpu.html#gade1463bb6f0e53ab480be27ac0b4383c":[10,8,9,0,17],
-"group__spa__cpu.html#gae10fa710c9aa3527eaf37d8a3bfd72d2":[10,8,9,0,26],
-"group__spa__cpu.html#gae496a2c1b18ae116ae1c2a7b7f0e66c3":[10,8,9,0,37]
+"group__spa__cpu.html#gadbf1c05dc94b098500b335c980a20f73":[10,8,9,0,27]
 };
