@@ -1,5 +1,10 @@
 var NAVTREEINDEX7 =
 {
+"group__spa__cpu.html#gade1463bb6f0e53ab480be27ac0b4383c":[10,8,9,0,17],
+"group__spa__cpu.html#gae10fa710c9aa3527eaf37d8a3bfd72d2":[10,8,9,0,26],
+"group__spa__cpu.html#gae496a2c1b18ae116ae1c2a7b7f0e66c3":[10,8,9,0,37],
+"group__spa__cpu.html#gaeaa02c7399c9c2e26501e6e220dd9910":[10,8,9,0,40],
+"group__spa__cpu.html#gaefc0478de60eb509f0c7b571d1a58622":[10,8,9,0,51],
 "group__spa__cpu.html#gaf0b85f94092b16c66534cd3206c30870":[10,8,9,0,55],
 "group__spa__cpu.html#gafd7cd22cbf0138875264c22ea79eef16":[10,8,9,0,56],
 "group__spa__dbus.html":[10,8,9,1],
@@ -244,10 +249,5 @@ var NAVTREEINDEX7 =
 "group__spa__json.html#ga6864ecec42015a48aa8991d6a2c8d6fa":[10,8,8,6,32],
 "group__spa__json.html#ga6c02b51e71c406e5b7f014858bdf579b":[10,8,8,6,25],
 "group__spa__json.html#ga6d871debd28993273c3cbb1b0f7fce64":[10,8,8,6,2],
-"group__spa__json.html#ga7c080249c08879b0576e5225a67fde7e":[10,8,8,6,19],
-"group__spa__json.html#ga8e5fa24c312810edffc063169e55497d":[10,8,8,6,13],
-"group__spa__json.html#ga910d92b40deefb1451ddcdee9b96c243":[10,8,8,6,27],
-"group__spa__json.html#ga9110761cf050dd015410b949edd24350":[10,8,8,6,15],
-"group__spa__json.html#ga9e5319ac5846fb6219a973e0cfa46786":[10,8,8,6,3],
-"group__spa__json.html#gab03680b46f934bdc18755d2156077cf1":[10,8,8,6,33]
+"group__spa__json.html#ga7c080249c08879b0576e5225a67fde7e":[10,8,8,6,19]
 };
